# husqvarna_automower_py
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/de131f1427a94cf68464204139e52326)](https://www.codacy.com/gh/Thomas55555/husqvarna_automower_py/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Thomas55555/husqvarna_automower_py&amp;utm_campaign=Badge_Grade)

Package to communicate with the Automower Connect API
